context("canvasXpress Web Charts - Dashboard")


test_that("cXdashboard1", {
    check_ui_test(cXdashboard1())
})

test_that("cXdashboard2", {
    check_ui_test(cXdashboard2())
})

test_that("cXdashboard3", {
    check_ui_test(cXdashboard3())
})

test_that("cXdashboard4", {
    check_ui_test(cXdashboard4())
})

test_that("cXdashboard5", {
    check_ui_test(cXdashboard5())
})

test_that("cXdashboard6", {
    check_ui_test(cXdashboard6())
})
